@@ -380,10 +380,14 @@ void PrintFormatNumber(void * ValuePtr, int Format, int ByteCount)
             case FMT_SLONG:     printf("%d",Get32s(ValuePtr)); s=4;      break;
             case FMT_SSHORT:    printf("%hd",(signed short)Get16u(ValuePtr)); s=2; break;
             case FMT_URATIONAL:
+                printf("%u/%u",Get32s(ValuePtr), Get32s(4+(char *)ValuePtr)); 
+                s = 8;
+                break;
+
             case FMT_SRATIONAL: 
-               printf("%d/%d",Get32s(ValuePtr), Get32s(4+(char *)ValuePtr)); 
-               s = 8;
-               break;
+                printf("%d/%d",Get32s(ValuePtr), Get32s(4+(char *)ValuePtr)); 
+                s = 8;
+                break;
 
             case FMT_SINGLE:    printf("%f",(double)*(float *)ValuePtr); s=8; break;
             case FMT_DOUBLE:    printf("%f",*(double *)ValuePtr);        s=8; break;
@@ -425,7 +429,11 @@ double ConvertAnyFormat(void * ValuePtr, int Format)
                 if (Den == 0){
                     Value = 0;
                 }else{
-                    Value = (double)Num/Den;
+                    if (Format == FMT_SRATIONAL){
+                        Value = (double)Num/Den;
+                    }else{
+                        Value = (double)(unsigned)Num/(double)(unsigned)Den;
+                    }
                 }
                 break;
             }
@@ -815,10 +823,6 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
 
             case TAG_ISO_EQUIVALENT:
                 ImageInfo.ISOequivalent = (int)ConvertAnyFormat(ValuePtr, Format);
-                if ( ImageInfo.ISOequivalent < 50 ){
-                    // Fixes strange encoding on some older digicams.
-                    ImageInfo.ISOequivalent *= 200;
-                }
                 break;
 
             case TAG_DIGITALZOOMRATIO:
@@ -860,7 +864,7 @@ static void ProcessExifDir(unsigned char * DirStart, unsigned char * OffsetBase,
                     if (SubdirStart < OffsetBase || SubdirStart > OffsetBase+ExifLength){
                         ErrNonfatal("Illegal GPS directory link in Exif",0,0);
                     }else{
-                        ProcessGpsInfo(SubdirStart, ByteCount, OffsetBase, ExifLength);
+                        ProcessGpsInfo(SubdirStart, OffsetBase, ExifLength);
                     }
                     continue;
                 }
@@ -1044,7 +1048,7 @@ void process_EXIF (unsigned char * ExifSection, unsigned int length)
 
 
     // Compute the CCD width, in millimeters.
-    if (FocalplaneXRes != 0){
+    if (FocalplaneXRes != 0 && ExifImageWidth != 0){
         // Note: With some cameras, its not possible to compute this correctly because
         // they don't adjust the indicated focal plane resolution units when using less
         // than maximum resolution, so the CCDWidth value comes out too small.  Nothing
@@ -1237,52 +1241,6 @@ const char * ClearOrientation(void)
     return OrientTab[ImageInfo.Orientation];
 }
 
-
-
-//--------------------------------------------------------------------------
-// Remove thumbnail out of the exif image.
-//--------------------------------------------------------------------------
-int RemoveThumbnail(unsigned char * ExifSection)
-{
-    if (!DirWithThumbnailPtrs || 
-        ImageInfo.ThumbnailOffset == 0 || 
-        ImageInfo.ThumbnailSize == 0){
-        // No thumbnail, or already deleted it.
-        return 0;
-    }
-    if (ImageInfo.ThumbnailAtEnd == FALSE){
-        ErrNonfatal("Thumbnail not at end of Exif header, can't remove it", 0, 0);
-        return 0;
-    }
-
-    {
-        int de;
-        int NumDirEntries;
-        NumDirEntries = Get16u(DirWithThumbnailPtrs);
-
-        for (de=0;de<NumDirEntries;de++){
-            int Tag;
-            unsigned char * DirEntry;
-            DirEntry = DIR_ENTRY_ADDR(DirWithThumbnailPtrs, de);
-            Tag = Get16u(DirEntry);
-            if (Tag == TAG_THUMBNAIL_LENGTH){
-                // Set length to zero.
-                if (Get16u(DirEntry+2) != FMT_ULONG){
-                    // non standard format encoding.  Can't do it.
-                    ErrNonfatal("Can't remove Exif thumbnail", 0, 0);
-                    return 0;
-                }
-                Put32u(DirEntry+8, 0);
-            }                    
-        }
-    }
-
-    // This is how far the non thumbnail data went.
-    return ImageInfo.ThumbnailOffset+8;
-
-}
-
-
 //--------------------------------------------------------------------------
 // Convert exif time to Unix time structure
 //--------------------------------------------------------------------------
@@ -1547,7 +1505,7 @@ void ShowImageInfo(int ShowFileInfo)
     if (ImageInfo.Process != M_SOF0){
         // don't show it if its the plain old boring 'baseline' process, but do
         // show it if its something else, like 'progressive' (used on web sometimes)
-        int a;
+        unsigned a;
         for (a=0;;a++){
             if (a >= PROCESS_TABLE_SIZE){
                 // ran off the end of the table.
@@ -1567,6 +1525,10 @@ void ShowImageInfo(int ShowFileInfo)
         if (ImageInfo.GpsAlt[0]) printf("GPS Altitude : %s\n",ImageInfo.GpsAlt);
     }
 
+    if (ImageInfo.QualityGuess){
+        printf("JPEG Quality : %d\n", ImageInfo.QualityGuess);
+    }
+
     // Print the comment. Print 'Comment:' for each new line of comment.
     if (ImageInfo.Comments[0]){
         int a,c;
