@@ -98,7 +98,7 @@ static void process_SOFn (const uchar * Data, int marker)
 //--------------------------------------------------------------------------
 // Check sections array to see if it needs to be increased in size.
 //--------------------------------------------------------------------------
-void CheckSectionsAllocated(void)
+static void CheckSectionsAllocated(void)
 {
     if (SectionsRead > SectionsAllocated){
         ErrFatal("allocation screwup");
@@ -143,6 +143,9 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
         for (a=0;;a++){
             marker = fgetc(infile);
             if (marker != 0xff && prev == 0xff) break;
+            if (marker == EOF){
+                ErrFatal("Unexpected end of file");
+            }
             prev = marker;
         }
 
@@ -155,6 +158,9 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
         // Read the length of the section.
         lh = fgetc(infile);
         ll = fgetc(infile);
+        if (lh == EOF || ll == EOF){
+            ErrFatal("Unexpected end of file");
+        }
 
         itemlen = (lh << 8) | ll;
 
@@ -212,6 +218,17 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
                 }
                 return TRUE;
 
+            case M_DQT:
+                // Use for jpeg quality guessing
+                process_DQT(Data, itemlen);
+                break;
+
+            case M_DHT:   
+                // Use for jpeg quality guessing
+                process_DHT(Data, itemlen);
+                break;
+
+
             case M_EOI:   // in case it's a tables-only JPEG stream
                 fprintf(stderr,"No image in jpeg!\n");
                 return FALSE;
@@ -357,7 +374,13 @@ int ReadJpegFile(const char * FileName, ReadMode_t ReadMode)
     // Scan the JPEG headers.
     ret = ReadJpegSections(infile, ReadMode);
     if (!ret){
-        fprintf(stderr,"Not JPEG: %s\n",FileName);
+        if (ReadMode == READ_ANY){
+            // Process any files mode.  Ignore the fact that it's not
+            // a jpeg file.
+            ret = TRUE;
+        }else{
+            fprintf(stderr,"Not JPEG: %s\n",FileName);
+        }
     }
 
     fclose(infile);
@@ -696,12 +719,17 @@ Section_t * CreateSection(int SectionType, unsigned char * Data, int Size)
     Section_t * NewSection;
     int a;
     int NewIndex;
-    NewIndex = 2;
 
-    if (SectionType == M_EXIF) NewIndex = 0; // Exif alwas goes first!
-
-    // Insert it in third position - seems like a safe place to put 
-    // things like comments.
+    NewIndex = 0; // Figure out where to put the comment section.
+    if (SectionType == M_EXIF){
+        // Exif alwas goes first!
+    }else{
+        for (;NewIndex < 3;NewIndex++){ // Maximum fourth position (just for the heck of it)
+            if (Sections[NewIndex].Type == M_JFIF) continue; // Put it after Jfif
+            if (Sections[NewIndex].Type == M_EXIF) continue; // Put it after Exif
+            break;
+        }
+    }
 
     if (SectionsRead < NewIndex){
         ErrFatal("Too few sections!");
